@@ -625,6 +625,7 @@ connect_ip6_page (CEPageIP6 *page)
                                            METHOD_COL_NAME, _("Link-Local Only"),
                                            METHOD_COL_METHOD, IP6_METHOD_LINK_LOCAL,
                                            -1);
+        g_object_unref (G_OBJECT (store));
 
         gtk_combo_box_set_model (page->method, GTK_TREE_MODEL (store));
 
@@ -644,6 +645,7 @@ connect_ip6_page (CEPageIP6 *page)
         page->never_default = GTK_WIDGET (gtk_builder_get_object (CE_PAGE (page)->builder, "never_default_check"));
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->never_default),
                                       nm_setting_ip6_config_get_never_default (page->setting));
+        g_signal_connect_swapped (page->never_default, "toggled", G_CALLBACK (ce_page_changed), page);
 
         g_signal_connect (page->method, "changed", G_CALLBACK (method_changed), page);
         if (method != IP6_METHOD_SHARED && method != IP6_METHOD_IGNORE)
@@ -681,7 +683,11 @@ ui_to_setting (CEPageIP6 *page)
         }
 
         nm_setting_ip6_config_clear_addresses (page->setting);
-        children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
+        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
+                children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
+        else
+                children = NULL;
+
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
@@ -752,7 +758,13 @@ ui_to_setting (CEPageIP6 *page)
         g_list_free (children);
 
         nm_setting_ip6_config_clear_dns (page->setting);
-        children = gtk_container_get_children (GTK_CONTAINER (page->dns_list));
+        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_AUTO) ||
+            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_DHCP) ||
+            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
+                children = gtk_container_get_children (GTK_CONTAINER (page->dns_list));
+        else
+                children = NULL;
+
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
@@ -781,7 +793,13 @@ ui_to_setting (CEPageIP6 *page)
         g_list_free (children);
 
         nm_setting_ip6_config_clear_routes (page->setting);
-        children = gtk_container_get_children (GTK_CONTAINER (page->routes_list));
+        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_AUTO) ||
+            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_DHCP) ||
+            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
+                children = gtk_container_get_children (GTK_CONTAINER (page->routes_list));
+        else
+                children = NULL;
+
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
